@@ -111,7 +111,7 @@ class Mongoer:
 
     def update_one(self, query: dict, data: BaseModel|dict, db:str=None, col:str=None, upsert=True)->dict:
         return self.getConnect(db,col).update_one(query, {'$set': data.model_dump() if isinstance(data,BaseModel) else data}, upsert=upsert).raw_result
-    
+                                                  
     async def aupdate_one(self, query: dict, data: BaseModel|dict, db:str=None, col:str=None, upsert=True)->dict:
         return (await self.getAConnect(db,col).update_one(query, {'$set': data.model_dump() if isinstance(data,BaseModel) else data}, upsert=upsert)).raw_result
 
@@ -121,6 +121,14 @@ class Mongoer:
     async def aupdate(self, query: dict, dt:dict, db:str=None, col:str=None)->dict:
         return (await self.getAConnect(db,col).update_many(query, {'$set': dt})).raw_result
 
+    def del_field(self, query: dict, *fields: str, db:str=None, col:str=None)->dict:
+        assert fields
+        return self.getConnect(db,col).update_many(query, {'$unset':{f:'' for f in fields}}).raw_result
+    
+    async def adel_field(self, query: dict, *fields: str, db:str=None, col:str=None)->dict:
+        assert fields
+        return (await self.getAConnect(db,col).update_many(query, {'$unset':{f:'' for f in fields}})).raw_result
+    
     def pop(self, query: dict,db:str=None, col:str=None)->dict|None:
         try:
             dt = self.getConnect(db,col).find_one_and_delete(query) or {}
